@@ -83,7 +83,7 @@ ddcorAll <- function(inputMat, design, compare, inputMatB = NULL, splitSet = NUL
 
 	##############################
 	#set SAF to FALSE while restoring to default when the function is finished
-	SAF = getOption("stringsAsFactors")
+	SAF = getOption("stringsAsFactors", FALSE)
 	on.exit(options(stringsAsFactors = SAF))
 	options(stringsAsFactors = FALSE)
 
